summaryrefslogtreecommitdiff
path: root/apps/CA.sh
diff options
context:
space:
mode:
Diffstat (limited to 'apps/CA.sh')
-rw-r--r--apps/CA.sh14
1 files changed, 8 insertions, 6 deletions
diff --git a/apps/CA.sh b/apps/CA.sh
index 1942b985a..030a11fc2 100644
--- a/apps/CA.sh
+++ b/apps/CA.sh
@@ -27,14 +27,16 @@
# tjh@cryptsoft.com
#
# default ssleay.cnf file has setup as per the following
# demoCA ... where everything is stored
+if [ -z "$OPENSSL" ]; then OPENSSL=openssl; fi
+
DAYS="-days 365"
-REQ="ssleay req $SSLEAY_CONFIG"
-CA="ssleay ca $SSLEAY_CONFIG"
-VERIFY="ssleay verify"
-X509="ssleay x509"
+REQ="$OPENSSL req $SSLEAY_CONFIG"
+CA="$OPENSSL ca $SSLEAY_CONFIG"
+VERIFY="$OPENSSL verify"
+X509="$OPENSSL x509"
CATOP=./demoCA
CAKEY=./cakey.pem
@@ -60,7 +62,7 @@ case $i in
echo "Request (and private key) is in newreq.pem"
;;
-newca)
- # if explictly asked for or it doesn't exist then setup the directory
+ # if explicitly asked for or it doesn't exist then setup the directory
# structure that Eric likes to manage things
NEW="1"
if [ "$NEW" -o ! -f ${CATOP}/serial ]; then
@@ -27,14 +27,16 @@
# tjh@cryptsoft.com
#
-# default ssleay.cnf file has setup as per the following
+# default openssl.cnf file has setup as per the following
# demoCA ... where everything is stored